@@ -9,7 +9,7 @@ stationary <- function(tpm) {
 	nr <- nrow(tpm)
 	rs <- all.equal(rowSums(tpm),rep(1,nr))
 	if(!(rs==TRUE)) stop("rows of the transition matrix should sum to unity")
-	e1 <- as.real(eigen(t(tpm))$vectors[,1])
+	e1 <- as.double(eigen(t(tpm))$vectors[,1])
 	e1 <- e1/sum(e1)
 	return(e1)
 }
